@@ -33,9 +33,15 @@ def sestav_svedeckou_vypoved():
     subprocess.Popen(['/usr/bin/python3', '-m', 'selen'])
     
     
+def zaplat_registraci():
+    #subprocess.Popen(['start', 'terms_conditions.txt'], shell=True) #pro widle
+    subprocess.Popen(['see', 'zaplat_registraci.pdf'])
+
+
 def sestav_particulars_of_claim():
     #subprocess.Popen(['start', 'terms_conditions.txt'], shell=True) #pro widle
     subprocess.Popen(['see', 'terms_conditions.pdf'])
 
+
 def sestav_bundle():
     subprocess.Popen(['/usr/bin/python3', '-m', 'create_bundle'])
